@@ -240,6 +240,11 @@ void App_Glom::init_menus()
                         sigc::mem_fun(*m_pFrame, &Frame_Glom::on_menu_Tables_EditTables) );
   m_listDeveloperActions.push_back(action);
 
+  action = Gtk::Action::create("GlomAction_Menu_AddRelatedTable", _("Add _Related Table"));
+  m_refActionGroup_Others->add(action,
+                        sigc::mem_fun(*m_pFrame, &Frame_Glom::on_menu_Tables_AddRelatedTable) );
+  m_listDeveloperActions.push_back(action);
+
 
   //"Reports" menu:
   m_refActionGroup_Others->add( Gtk::Action::create("Glom_Menu_Reports", _("_Reports")) );
@@ -327,6 +332,7 @@ void App_Glom::init_menus()
     "        <placeholder name='Menu_Tables_Dynamic' />"
     "        <separator />"
     "        <menuitem action='GlomAction_Menu_EditTables' />"
+    "        <menuitem action='GlomAction_Menu_AddRelatedTable' />"
     "     </menu>"
     "     <menu action='Glom_Menu_Reports'>"
     "        <placeholder name='Menu_Reports_Dynamic' />"
@@ -691,7 +697,7 @@ bool App_Glom::offer_new_or_existing()
           bool keep_asking = true;
           while(keep_asking)
           {
-            int response = dialog->run();
+            int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_new_database");
 
             if(response == Gtk::RESPONSE_OK)
             {
@@ -814,7 +820,7 @@ void App_Glom::init_menus_help()
 
 void App_Glom::on_menu_help_contents()
 {
-  gnome_help_display("glom", 0, 0);
+  Glom::Utils::show_help();
 }
 
 bool App_Glom::recreate_database(bool& user_cancelled)
@@ -1235,7 +1241,7 @@ void App_Glom::on_menu_developer_changelanguage()
     if(dialog)
     {
       dialog->set_transient_for(*this);
-      const int response = dialog->run();
+      const int response =       Glom::Utils::dialog_run_with_help(dialog, "dialog_change_language");
       dialog->hide();
 
       if(response == Gtk::RESPONSE_OK)
