@@ -92,8 +92,11 @@ void Dialog_FieldCalculation::on_button_test()
     }
   }
 
+  //We need the connection when we run the script, so that the script may use it.
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(this /* parent window */);
+
   Gnome::Gda::Value value = glom_evaluate_python_function_implementation(Field::TYPE_TEXT, calculation, field_values, //TODO: Maybe use the field's type here.
-    document, m_table_name);
+    document, m_table_name, sharedconnection->get_gda_connection());
 
   Frame_Glom::show_ok_dialog(_("Calculation result"), _("The result of the calculation is:\n") + value.to_string(), *this);
 
