@@ -23,6 +23,8 @@
 
 #include <gtkmm.h>
 
+namespace Glom
+{
 
 class FlowTable : public Gtk::Container
 {
@@ -116,4 +118,6 @@ protected:
   Glib::RefPtr<Gdk::GC> m_refGC;
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITYWIDGETS_FLOWTABLE_H
